RuntimeRequestReceipt

Struct RuntimeRequestReceipt 

pub struct RuntimeRequestReceipt {
    pub schema: String,
    pub request_id: String,
    pub unit_id: String,
    pub generation: u64,
    pub kind: RuntimeRequestKind,
    pub request_digest: String,
    pub deadline_at_ms: Option<u64>,
    pub state: RuntimeRequestState,
    pub observation: Option<RuntimeObservation>,
    pub removal: Option<RuntimeRemoval>,
    pub exec_result: Option<RuntimeExecResult>,
}

Fields

schema: Stringrequest_id: Stringunit_id: Stringgeneration: u64kind: RuntimeRequestKindrequest_digest: Stringdeadline_at_ms: Option<u64>

Effective absolute deadline captured when the request was first reserved.

Exec always has a deadline because its relative timeout is converted to an absolute value. Persisting it prevents a pending replay from extending the original execution budget.

state: RuntimeRequestStateobservation: Option<RuntimeObservation>removal: Option<RuntimeRemoval>exec_result: Option<RuntimeExecResult>

Implementations

Source

impl RuntimeRequestReceipt

pub const SCHEMA: &'static str = "a3s.runtime.request-receipt.v2"

pub fn validate(&self) -> Result<(), String>